import { sql } from "drizzle-orm";
import { int, sqliteTable as table, text } from "drizzle-orm/sqlite-core";

export const publisherTable = table("publisher", {
  id: int().primaryKey({ autoIncrement: true }),
  name: text().notNull().unique(),
  url: text().notNull().unique(),
});

export const sourceTable = table("source", {
  id: int().primaryKey({ autoIncrement: true }),
  name: text().notNull().unique(),
  url: text().notNull().unique(),
  publisherId: int("publisher_id").references(() => publisherTable.id),
});

export const chunkTable = table("chunk", {
  id: int().primaryKey({ autoIncrement: true }),
  name: text().notNull(),
  pages: text("pages", { mode: "json" }).notNull().$type<string[]>().default(sql`'[]'`),
  sourceId: int("source_id").references(() => sourceTable.id),
});

export const tableTable = table("table", {
  id: int().primaryKey({ autoIncrement: true }),
  name: text(),
  order: int().notNull().default(sql`0`),
  chunkId: int("chunk_id").notNull().references(() => chunkTable.id),
});

export const outcomeTable = table("outcome", {
  id: int().primaryKey({ autoIncrement: true }),
  name: text().notNull(),
  roll: int().notNull(),
  tableId: int("table_id").notNull().references(() => tableTable.id),
});
